Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/torch/nn.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClement Farabet <clement.farabet@gmail.com>2012-07-13 22:02:57 +0400
committerClement Farabet <clement.farabet@gmail.com>2012-07-13 22:02:57 +0400
commit14d04599b4c36f662db38befc5cd9fb105cf0407 (patch)
treea838c365dc63cc3ce3ba0d6c7a9476566b4c10b8
parentf61a5ccdcd0f8b8f87df63f3d18a445380c18b22 (diff)
Fixed outdated call.
-rw-r--r--hessian.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/hessian.lua b/hessian.lua
index 63fed12..fa0dece 100644
--- a/hessian.lua
+++ b/hessian.lua
@@ -378,8 +378,8 @@ function nn.hessian.enable()
end
----------------------------------------------------------------------
- -- Avoid multiple calls to activate()
+ -- Avoid multiple calls to enable()
----------------------------------------------------------------------
- function nn.hessian.activate()
+ function nn.hessian.enable()
end
end